﻿using Microsoft.AspNetCore.Components.Authorization;
using Microsoft.AspNetCore.Identity;
using Microsoft.EntityFrameworkCore;
using Newtonsoft.Json.Serialization;
using SCMSystem.Api.Application;
using SCMSystem.Api.Contract;
using SCMSystem.Api.DataContext;
using SCMSystem.Web.Areas.Identity;
using Syncfusion.Blazor;

var builder = WebApplication.CreateBuilder(args);

// Add services to the container.

var connectionString = builder.Configuration.GetConnectionString("DefaultConnection");
builder.Services.AddDbContext<SCMDbContext>(options =>
    options.UseSqlServer(connectionString,
    sqlServerOptionsAction: sqlOptions =>
    {
        sqlOptions.EnableRetryOnFailure();

    }));

builder.Services.AddIdentity<ApplicationUser, ApplicationRole>(options =>
{
    options.Stores.MaxLengthForKeys = 128;
    options.SignIn.RequireConfirmedAccount = true;
    options.SignIn.RequireConfirmedEmail = false;
})
         .AddEntityFrameworkStores<SCMDbContext>()
         .AddDefaultTokenProviders();

builder.Services.AddDatabaseDeveloperPageExceptionFilter();
builder.Services.AddServerSideBlazor().AddHubOptions(o => { o.MaximumReceiveMessageSize = 102400000; });
builder.Services.AddServerSideBlazor().AddCircuitOptions(options => { options.DetailedErrors = true; });
builder.Services.AddSyncfusionBlazor();

builder.Services.AddSyncfusionBlazor();

builder.Services.AddRazorPages();
builder.Services.AddControllers().AddNewtonsoftJson(options => { options.SerializerSettings.ContractResolver = new DefaultContractResolver(); });

builder.Services.AddSignalR(e => { e.MaximumReceiveMessageSize = 102400000; });

builder.Services.AddServerSideBlazor().AddHubOptions(o=>
            {
                o.MaximumReceiveMessageSize=102400000;
            });

builder.Services.AddScoped<ISupportService, SupportService>();
builder.Services.AddScoped<IUserService, UserService>();
builder.Services.AddScoped<IBidService, BidService>();
builder.Services.AddScoped<IBidCommitteeService, BidCommitteeService>();
builder.Services.AddScoped<IProcurementPlanService, ProcurementPlanService>();
builder.Services.AddScoped<IRFQService, RFQService>();
builder.Services.AddScoped<IBECService, BECService>();
builder.Services.AddScoped<IBidderService, BidderService>();
builder.Services.AddScoped<IFinanceService, FinanceService>();
builder.Services.AddScoped<ITenderService, TenderService>();
builder.Services.AddScoped<IReportService, ReportService>();
builder.Services.AddScoped<IMeetingService, MeetingService>();
builder.Services.AddScoped<ISupplierPanelService, SupplierPanelService>();
builder.Services.AddScoped<IUserDepartmentService, UserDepartmentService>();
builder.Services.AddScoped<IConstructionService, ConstructionService>();


builder.Services.AddScoped<AuthenticationStateProvider, RevalidatingIdentityAuthenticationStateProvider<ApplicationUser>>();
string sfLicense = "NzI3MTA1QDMyMzAyZTMzMmUzMGErNWpZSmpuQVJ0djB2dkx5K2NHN3dTUTFqYjgwWjdVNXlGVFd2RDdERlU9";
//string sfLicense = "NjY3MDc5QDMyMzAyZTMyMmUzMGVweDlBNlQvWkpTMkpJUktsZGw1dFRMNGsrZUh6TmxIN3lFOTBqRFVQaHM9";
Syncfusion.Licensing.SyncfusionLicenseProvider.RegisterLicense(sfLicense);

var app = builder.Build();

// Configure the HTTP request pipeline.
if (app.Environment.IsDevelopment())
{
    app.UseMigrationsEndPoint();
}
else
{
    app.UseExceptionHandler("/Error");
    // The default HSTS value is 30 days. You may want to change this for production scenarios, see https://aka.ms/aspnetcore-hsts.
    app.UseHsts();
}

app.UseHttpsRedirection();

app.UseStaticFiles();
app.UseFastReport();

app.UseRouting();
app.UseCors();

app.UseAuthentication();
app.UseAuthorization();

app.MapControllers();
app.MapDefaultControllerRoute();
            app.MapBlazorHub();
app.MapFallbackToPage("/_Host");

app.Run();
